@@ -17,10 +17,11 @@ Example:
 >>> Foo.match_to_schema([u"hey there", {u"world": 123}])
 >>> Foo.match_to_schema([u"foo", 1337, u"bar"])
 'bli'
+
+See json_schema.tokens for more.
 """
 
 from json_schema.defs import *
-from json_schema.validator import validate as validate_json_schema
 from json_schema.schema import SchemaCollection, Schema
 
 if __name__ == "__main__":
